@@ -509,11 +509,11 @@ failed to upload.</source>
 <context>
     <name>DaemonManager</name>
     <message>
-        <source>failed to load ccnet config dir %1</source>
-        <translation>nepodarilo sa nahrať ccnet konfiguračný adresár %1</translation>
+        <source>%1 client failed to initialize</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>%1 client failed to initialize</source>
+        <source>%1 exited unexpectedly</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -850,6 +850,10 @@ failed to upload.</source>
         <source>Search files</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -920,10 +924,6 @@ failed to upload.</source>
         <source>Last Modified</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Kind</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>FileBrowserSearchView</name>
@@ -981,7 +981,7 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Kind</source>
+        <source>Modifier</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1081,6 +1081,13 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>FinderSyncHost</name>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>GetFileTask</name>
     <message>
@@ -1464,20 +1471,15 @@ Do you like to download your default library?</source>
     </message>
 </context>
 <context>
-    <name>MessageListener</name>
-    <message>
-        <source>failed to load ccnet config dir </source>
-        <translation>nepodarilo sa nahrať ccnet konfiguračný adresár</translation>
-    </message>
+    <name>MessagePoller</name>
     <message>
         <source>&quot;%1&quot; is unsynced. 
 Reason: Deleted on server</source>
-        <translation>&quot;%1&quot; je nesynchronizovaná. 
-Dôvod: Zmazaná na servery</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; is synchronized</source>
-        <translation>&quot;%1&quot; je synchronizovaná</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Files uploaded to &quot;%1&quot;</source>
@@ -1497,6 +1499,16 @@ File is locked by other application. This file will be updated when you close th
 Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to sync file %1
+File is locked by another user. Update to this file is not uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to index file %1
+Please check file permission and disk space.</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Failed to sync %1
 File path is ended with space or period and cannot be created on Windows.</source>
@@ -1508,29 +1520,17 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Failed to index file %1
-Please check file permission and disk space.</source>
+        <source>Update to file %1 is denied by folder permission setting.</source>
         <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; failed to sync. 
 Access denied to service</source>
-        <translation>&quot;%1&quot; sa nepodarilo zosynchronizovať. 
-Prístup k službe bol odmietnutý</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; failed to sync.
 The library owner&apos;s storage space is used up.</source>
-        <translation>&quot;%1&quot; sa nepodarilo zosynchronizovať.
-Diskový priestor vlastníka knižnice je zaplnený.</translation>
-    </message>
-    <message>
-        <source>Update to file %1 is denied by folder permission setting.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to sync file %1
-File is locked by another user. Update to this file is not uploaded.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1699,18 +1699,10 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Failed to start upload</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occured in upload</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to start download</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occured in download</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Library is damaged on server</source>
         <translation type="unfinished"/>
@@ -2043,14 +2035,6 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>&lt;Not Part of Certificate&gt;</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Found another running process of %1, kill it and start a new one?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Sync this library to:</source>
         <translation type="unfinished"/>
@@ -2155,6 +2139,18 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Update to file denied by folder permission setting</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Client is already running</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Error occurred in upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Error occurred in download</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2530,6 +2526,22 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Cancel</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>failed to save client id</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>failed to access %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>incorrect client id</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>failed to read %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileLinkDialog</name>
@@ -2541,29 +2553,25 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Copy to clipboard</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>%1 Web Link:</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>%1 Protocol Link:</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>OK</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Internal Link:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileRpcClient</name>
-    <message>
-        <source>failed to load ccnet config dir %1</source>
-        <translation>nepodarilo sa načítať ccnet konfiguračný adresár %1</translation>
-    </message>
     <message>
         <source>Unknown error</source>
         <translation>Neznáma chyba</translation>
     </message>
+    <message>
+        <source>internal error: failed to connect to daemon</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileTrayIcon</name>
