@@ -504,11 +504,11 @@ failed to upload.</source>
 <context>
     <name>DaemonManager</name>
     <message>
-        <source>failed to load ccnet config dir %1</source>
+        <source>%1 client failed to initialize</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>%1 client failed to initialize</source>
+        <source>%1 exited unexpectedly</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -844,6 +844,10 @@ failed to upload.</source>
         <source>Search files</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -914,10 +918,6 @@ failed to upload.</source>
         <source>Last Modified</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Kind</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>FileBrowserSearchView</name>
@@ -975,7 +975,7 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Kind</source>
+        <source>Modifier</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1075,6 +1075,13 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>FinderSyncHost</name>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>GetFileTask</name>
     <message>
@@ -1453,20 +1460,15 @@ Do you like to download your default library?</source>
     </message>
 </context>
 <context>
-    <name>MessageListener</name>
-    <message>
-        <source>failed to load ccnet config dir </source>
-        <translation type="unfinished"/>
-    </message>
+    <name>MessagePoller</name>
     <message>
         <source>&quot;%1&quot; is unsynced. 
 Reason: Deleted on server</source>
-        <translation>&quot;%1&quot; är inte synkroniserad.
-Anledning: Borttagen på server</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>&quot;%1&quot; is synchronized</source>
-        <translation>&quot;%1&quot; är synkroniserad</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Files uploaded to &quot;%1&quot;</source>
@@ -1486,6 +1488,16 @@ File is locked by other application. This file will be updated when you close th
 Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to sync file %1
+File is locked by another user. Update to this file is not uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to index file %1
+Please check file permission and disk space.</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Failed to sync %1
 File path is ended with space or period and cannot be created on Windows.</source>
@@ -1497,8 +1509,7 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Failed to index file %1
-Please check file permission and disk space.</source>
+        <source>Update to file %1 is denied by folder permission setting.</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -1511,15 +1522,6 @@ Access denied to service</source>
 The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Update to file %1 is denied by folder permission setting.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to sync file %1
-File is locked by another user. Update to this file is not uploaded.</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -1686,18 +1688,10 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Failed to start upload</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occured in upload</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to start download</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occured in download</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Library is damaged on server</source>
         <translation type="unfinished"/>
@@ -2030,14 +2024,6 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>&lt;Not Part of Certificate&gt;</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Found another running process of %1, kill it and start a new one?</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Sync this library to:</source>
         <translation type="unfinished"/>
@@ -2142,6 +2128,18 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Update to file denied by folder permission setting</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Client is already running</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Error occurred in upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Error occurred in download</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2515,6 +2513,22 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Cancel</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>failed to save client id</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>failed to access %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>incorrect client id</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>failed to read %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileLinkDialog</name>
@@ -2526,27 +2540,23 @@ File is locked by another user. Update to this file is not uploaded.</source>
         <source>Copy to clipboard</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>%1 Web Link:</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>%1 Protocol Link:</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>OK</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Internal Link:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileRpcClient</name>
     <message>
-        <source>failed to load ccnet config dir %1</source>
+        <source>Unknown error</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Unknown error</source>
+        <source>internal error: failed to connect to daemon</source>
         <translation type="unfinished"/>
     </message>
 </context>
